"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var application_1 = require("@jupyterlab/application");
var docmanager_1 = require("@jupyterlab/docmanager");
var fileeditor_1 = require("@jupyterlab/fileeditor");
var notebook_1 = require("@jupyterlab/notebook");
var rendermime_1 = require("@jupyterlab/rendermime");
var toc_1 = require("./toc");
var generators_1 = require("./generators");
var registry_1 = require("./registry");
require("../style/index.css");
/**
 * Initialization data for the jupyterlab-toc extension.
 */
var extension = {
    id: 'jupyterlab-toc',
    autoStart: true,
    provides: registry_1.ITableOfContentsRegistry,
    requires: [
        docmanager_1.IDocumentManager,
        fileeditor_1.IEditorTracker,
        application_1.ILayoutRestorer,
        notebook_1.INotebookTracker,
        rendermime_1.IRenderMimeRegistry,
    ],
    activate: activateTOC,
};
/**
 * Activate the ToC extension.
 */
function activateTOC(app, docmanager, editorTracker, restorer, notebookTracker, rendermime) {
    // Create the ToC widget.
    var toc = new toc_1.TableOfContents({ docmanager: docmanager, rendermime: rendermime });
    // Create the ToC registry.
    var registry = new registry_1.TableOfContentsRegistry();
    // Add the ToC to the left area.
    toc.title.label = 'Contents';
    toc.id = 'table-of-contents';
    app.shell.addToLeftArea(toc, { rank: 700 });
    // Add the ToC widget to the application restorer.
    restorer.add(toc, 'juputerlab-toc');
    // Create a notebook TableOfContentsRegistry.IGenerator
    var notebookGenerator = generators_1.createNotebookGenerator(notebookTracker, rendermime.sanitizer);
    registry.addGenerator(notebookGenerator);
    // Create an markdown editor TableOfContentsRegistry.IGenerator
    var markdownGenerator = generators_1.createMarkdownGenerator(editorTracker);
    registry.addGenerator(markdownGenerator);
    // Create a latex editor TableOfContentsRegistry.IGenerator
    var latexGenerator = generators_1.createLatexGenerator(editorTracker);
    registry.addGenerator(latexGenerator);
    // Change the ToC when the active widget changes.
    app.shell.currentChanged.connect(function () {
        var widget = app.shell.currentWidget;
        if (!widget) {
            return;
        }
        var generator = registry.findGeneratorForWidget(widget);
        if (!generator) {
            // If the previously used widget is still available, stick with it.
            // Otherwise, set the current TOC widget to null.
            if (toc.current && toc.current.widget.isDisposed) {
                toc.current = null;
            }
            return;
        }
        toc.current = { widget: widget, generator: generator };
    });
    return registry;
}
exports.default = extension;
