import { IInstanceTracker } from '@jupyterlab/apputils';
import { Token } from '@phosphor/coreutils';
import { Widget } from '@phosphor/widgets';
import { IHeading } from './toc';
/**
 * An interface for a TableOfContentsRegistry.
 */
export interface ITableOfContentsRegistry extends TableOfContentsRegistry {
}
/**
 * The TableOfContentsRegistry token.
 */
export declare const ITableOfContentsRegistry: Token<TableOfContentsRegistry>;
/**
 * A class that keeps track of the different kinds
 * of widgets for which there can be tables-of-contents.
 */
export declare class TableOfContentsRegistry {
    /**
     * Given a widget, find an IGenerator for it,
     * or undefined if none can be found.
     */
    findGeneratorForWidget(widget: Widget): TableOfContentsRegistry.IGenerator | undefined;
    /**
     * Add a new IGenerator to the registry.
     */
    addGenerator(generator: TableOfContentsRegistry.IGenerator): void;
    private _generators;
}
/**
 * A namespace for TableOfContentsRegistry statics.
 */
export declare namespace TableOfContentsRegistry {
    /**
     * An interface for an object that knows how to generate a table-of-contents
     * for a type of widget.
     */
    interface IGenerator<W extends Widget = Widget> {
        /**
         * An instance tracker for the widget.
         */
        tracker: IInstanceTracker<W>;
        /**
         * A function to test whether to generate a ToC for a widget.
         *
         * #### Notes
         * By default is assumed to be enabled if the widget
         * is hosted in `tracker`. However, the user may want to add
         * additional checks. For instance, this can be used to generate
         * a ToC for text files only if they have a given mimeType.
         */
        isEnabled?: (widget: W) => boolean;
        /**
         * Whether the document uses LaTeX typesetting.
         *
         * Defaults to `false`.
         */
        usesLatex?: boolean;
        /**
         * A function that takes the widget, and produces
         * a list of headings.
         */
        generate(widget: W): IHeading[];
    }
}
