"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var coreutils_1 = require("@phosphor/coreutils");
;
/* tslint:disable */
/**
 * The TableOfContentsRegistry token.
 */
exports.ITableOfContentsRegistry = new coreutils_1.Token('jupyterlab-toc:ITableOfContentsRegistry');
/* tslint:enable */
/**
 * A class that keeps track of the different kinds
 * of widgets for which there can be tables-of-contents.
 */
var TableOfContentsRegistry = /** @class */ (function () {
    function TableOfContentsRegistry() {
        this._generators = [];
    }
    /**
     * Given a widget, find an IGenerator for it,
     * or undefined if none can be found.
     */
    TableOfContentsRegistry.prototype.findGeneratorForWidget = function (widget) {
        var generator;
        this._generators.forEach(function (gen) {
            if (gen.tracker.has(widget)) {
                // If isEnabled is present, check for it.
                if (gen.isEnabled && !gen.isEnabled(widget)) {
                    return;
                }
                generator = gen;
            }
        });
        return generator;
    };
    /**
     * Add a new IGenerator to the registry.
     */
    TableOfContentsRegistry.prototype.addGenerator = function (generator) {
        this._generators.push(generator);
    };
    return TableOfContentsRegistry;
}());
exports.TableOfContentsRegistry = TableOfContentsRegistry;
