/// <reference types="react" />
import { IDocumentManager } from '@jupyterlab/docmanager';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { Message } from '@phosphor/messaging';
import { Widget } from '@phosphor/widgets';
import { TableOfContentsRegistry } from './registry';
import * as React from 'react';
/**
 * A widget for hosting a notebook table-of-contents.
 */
export declare class TableOfContents extends Widget {
    /**
     * Create a new table of contents.
     */
    constructor(options: TableOfContents.IOptions);
    /**
     * The current widget-generator tuple for the ToC.
     */
    current: TableOfContents.ICurrentWidget | null;
    /**
     * Handle an update request.
     */
    protected onUpdateRequest(msg: Message): void;
    /**
     * Rerender after showing.
     */
    protected onAfterShow(msg: Message): void;
    private _rendermime;
    private _docmanager;
    private _current;
    private _monitor;
}
/**
 * A namespace for TableOfContents statics.
 */
export declare namespace TableOfContents {
    /**
     * Options for the constructor.
     */
    interface IOptions {
        /**
         * The document manager for the application.
         */
        docmanager: IDocumentManager;
        /**
         * The rendermime for the application.
         */
        rendermime: IRenderMimeRegistry;
    }
    /**
     * A type representing a tuple of a widget,
     * and a generator that knows how to generate
     * heading information from that widget.
     */
    interface ICurrentWidget<W extends Widget = Widget> {
        widget: W;
        generator: TableOfContentsRegistry.IGenerator<W>;
    }
}
/**
 * An object that represents a heading.
 */
export interface IHeading {
    /**
     * The text of the heading.
     */
    text: string;
    /**
     * The HTML header level for the heading.
     */
    level: number;
    /**
     * A function to execute when clicking the ToC
     * item. Typically this will be used to scroll
     * the parent widget to this item.
     */
    onClick: () => void;
    /**
     * If there is special markup, we can instead
     * render the heading using a raw HTML string. This
     * HTML *should be properly sanitized!*
     *
     * For instance, this can be used to render
     * already-renderd-to-html markdown headings.
     */
    html?: string;
}
/**
 * Props for the TOCTree component.
 */
export interface ITOCTreeProps extends React.Props<TOCTree> {
    /**
     * A title to display.
     */
    title: string;
    /**
     * A list of IHeadings to render.
     */
    toc: IHeading[];
}
/**
 * Props for the TOCItem component.
 */
export interface ITOCItemProps extends React.Props<TOCItem> {
    /**
     * An IHeading to render.
     */
    heading: IHeading;
}
/**
 * A React component for a table of contents entry.
 */
export declare class TOCItem extends React.Component<ITOCItemProps, {}> {
    /**
     * Render the item.
     */
    render(): JSX.Element;
}
/**
 * A React component for a table of contents.
 */
export declare class TOCTree extends React.Component<ITOCTreeProps, {}> {
    /**
     * Render the TOCTree.
     */
    render(): JSX.Element;
}
