"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var coreutils_1 = require("@jupyterlab/coreutils");
var widgets_1 = require("@phosphor/widgets");
var React = require("react");
var ReactDOM = require("react-dom");
/**
 * Timeout for throttling TOC rendering.
 */
var RENDER_TIMEOUT = 1000;
/**
 * A widget for hosting a notebook table-of-contents.
 */
var TableOfContents = /** @class */ (function (_super) {
    __extends(TableOfContents, _super);
    /**
     * Create a new table of contents.
     */
    function TableOfContents(options) {
        var _this = _super.call(this) || this;
        _this._docmanager = options.docmanager;
        _this._rendermime = options.rendermime;
        return _this;
    }
    Object.defineProperty(TableOfContents.prototype, "current", {
        /**
         * The current widget-generator tuple for the ToC.
         */
        get: function () {
            return this._current;
        },
        set: function (value) {
            // If they are the same as previously, do nothing.
            if (value &&
                this._current &&
                this._current.widget === value.widget &&
                this._current.generator === value.generator) {
                return;
            }
            this._current = value;
            // Dispose an old activity monitor if it existsd
            if (this._monitor) {
                this._monitor.dispose();
                this._monitor = null;
            }
            // If we are wiping the ToC, update and return.
            if (!this._current) {
                this.update();
                return;
            }
            // Find the document model associated with the widget.
            var context = this._docmanager.contextForWidget(this._current.widget);
            if (!context || !context.model) {
                throw Error('Could not find a context for the Table of Contents');
            }
            // Throttle the rendering rate of the table of contents.
            this._monitor = new coreutils_1.ActivityMonitor({
                signal: context.model.contentChanged,
                timeout: RENDER_TIMEOUT,
            });
            this._monitor.activityStopped.connect(this.update, this);
            this.update();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Handle an update request.
     */
    TableOfContents.prototype.onUpdateRequest = function (msg) {
        var _this = this;
        // Don't bother if the TOC is not visible
        if (!this.isVisible) {
            return;
        }
        var toc = [];
        var title = 'Table of Contents';
        if (this._current) {
            toc = this._current.generator.generate(this._current.widget);
            var context = this._docmanager.contextForWidget(this._current.widget);
            if (context) {
                title = coreutils_1.PathExt.basename(context.localPath);
            }
        }
        ReactDOM.render(React.createElement(TOCTree, { title: title, toc: toc }), this.node, function () {
            if (_this._current &&
                _this._current.generator.usesLatex === true &&
                _this._rendermime.latexTypesetter) {
                _this._rendermime.latexTypesetter.typeset(_this.node);
            }
        });
    };
    /**
     * Rerender after showing.
     */
    TableOfContents.prototype.onAfterShow = function (msg) {
        this.update();
    };
    return TableOfContents;
}(widgets_1.Widget));
exports.TableOfContents = TableOfContents;
/**
 * A React component for a table of contents entry.
 */
var TOCItem = /** @class */ (function (_super) {
    __extends(TOCItem, _super);
    function TOCItem() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Render the item.
     */
    TOCItem.prototype.render = function () {
        var heading = this.props.heading;
        var level = Math.round(heading.level);
        // Clamp the header level between 1 and six.
        level = Math.max(Math.min(level, 6), 1);
        // Create an onClick handler for the TOC item
        // that scrolls the anchor into view.
        var clickHandler = function (evt) {
            evt.preventDefault();
            evt.stopPropagation();
            heading.onClick();
        };
        if (heading.html) {
            var el = React.createElement("h" + level, {
                onClick: clickHandler,
                dangerouslySetInnerHTML: { __html: heading.html },
            });
            return React.createElement("a", { href: "" }, el);
        }
        else {
            return React.createElement("h" + level, { onClick: clickHandler }, React.createElement("a", { href: "" }, heading.text));
        }
    };
    return TOCItem;
}(React.Component));
exports.TOCItem = TOCItem;
/**
 * A React component for a table of contents.
 */
var TOCTree = /** @class */ (function (_super) {
    __extends(TOCTree, _super);
    function TOCTree() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Render the TOCTree.
     */
    TOCTree.prototype.render = function () {
        // Map the heading objects onto a list of JSX elements.
        var i = 0;
        var listing = this.props.toc.map(function (el) {
            return React.createElement(TOCItem, { heading: el, key: el.text + "-" + el.level + "-" + i++ });
        });
        // Return the JSX component.
        return (React.createElement("div", { className: "jp-TableOfContents" },
            React.createElement("div", { className: "jp-TableOfContents-header" },
                React.createElement("h1", null, this.props.title)),
            React.createElement("div", { className: "jp-TableOfContents-content" }, listing)));
    };
    return TOCTree;
}(React.Component));
exports.TOCTree = TOCTree;
